@@ -9,9 +9,6 @@
  *******************************************************************************/
 package org.eclipse.linuxtools.rdt.proxy.tests;
 
-import org.eclipse.linuxtools.rdt.proxy.tests.CommandLauncherProxyTest;
-import org.eclipse.linuxtools.rdt.proxy.tests.FileProxyTest;
-import org.eclipse.linuxtools.rdt.proxy.tests.RemoteProxyManagerTest;
 import org.junit.runner.RunWith;
 import org.junit.runners.Suite;
 import org.junit.runners.Suite.SuiteClasses;
